# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [v1.3.2] - 2025-09-12
### New Features
- [`183e39d`](https://github.com/HydroRoll-Team/OneRoll/commit/183e39d9ebfe6e48e5ce666dee36b5347d47f53e) - add unique modifier to dice calculations and parsing *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`899ca82`](https://github.com/HydroRoll-Team/OneRoll/commit/899ca820e34b1b62190e88da71cf734295974a19) - enhance dice modifiers with new options for aliasing, sorting, and counting *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`2778db8`](https://github.com/HydroRoll-Team/OneRoll/commit/2778db81c6973078dc0e8e04c4bb711143aef84d) - add new reroll modifiers for enhanced dice functionality *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

### Refactors
- [`745f886`](https://github.com/HydroRoll-Team/OneRoll/commit/745f886017e1a25be00a3d0634cd802126d936cd) - simplify grammar rules by removing unnecessary whitespace and comments *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

### Chores
- [`b5d9371`](https://github.com/HydroRoll-Team/OneRoll/commit/b5d9371d47f5e9b5789f746241eaa5bd4222314d) - update CI configuration for maturin v1.8.6 and enhance wheel building steps *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`b0a8fe3`](https://github.com/HydroRoll-Team/OneRoll/commit/b0a8fe3c3d28644bff9432abb68aa817d0db14ed) - update Python version to 3.11 in CI configuration *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`b8fa777`](https://github.com/HydroRoll-Team/OneRoll/commit/b8fa77736a3c3b9c9d898e7ffa87e057cfab005d) - update Python version in CI configuration to use 3.x for compatibility *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*
- [`88a6ddc`](https://github.com/HydroRoll-Team/OneRoll/commit/88a6ddcd196cc95964a8abc9c247884ece9028f6) - bump version into 1.3.2 *(commit by [@HsiangNianian](https://github.com/HsiangNianian))*

[v1.3.2]: https://github.com/HydroRoll-Team/OneRoll/compare/v1.0.2...v1.3.2
